@@ -191,6 +191,41 @@ class Crawler:
             self.randomsleep(self.sleeptime)
             self.semphore.release()
 
+
+    def httpget(self,i,maxcount,url):
+        print(f"{str(i+1)}/{maxcount}:{url}")
+        success = False
+        trynum = 0  # 设置最大请求次数
+        while not success and trynum<=self.maxtrynum:
+            try:
+                r = requests.get(url, headers=self.getHeaders(), verify=False, timeout=self.timeout)
+                if self.encoding=="":
+                    r.encoding = r.apparent_encoding
+                else:
+                    r.encoding=self.encoding
+                success = True
+                trynum += 1
+            except requests.exceptions.ConnectTimeout as e1:
+                # 超时
+                self.print_and_log(str(e1))
+                trynum+=1
+            except requests.exceptions.ConnectionError as e2:
+                # 远程主机强迫关闭了一个现有的连接
+                self.print_and_log(str(e2))
+                trynum += 1
+            except Exception as e:
+                self.print_and_log(str(e))
+                trynum += 1
+        if success:
+            sourcecode = r.text
+            if r.status_code == 200 and sourcecode != "":
+                self.save(self.parse(sourcecode,url))
+            else:
+                self.error("错误：" + str(r.status_code))
+        else:
+            self.error("无法访问：" + url)
+        self.randomsleep(self.sleeptime)
+
     def crawl(self,urls,stopstatus="404"):
         if not os.path.exists(f'{self.filename}.db'): self.createsqlite()
         threads=[]
@@ -199,4 +234,4 @@ class Crawler:
             threads.append(t)
         [t.start() for t in threads]
         [t.join() for t in threads]
-        print("爬取结束")
\ No newline at end of file
+        print("爬取结束")
